<?php

/**
 * mod_smenu_banner
 *
 * @version 2.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2008
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link http://www.creativepulse.eu
 */

defined('_JEXEC') or die('Restricted access');


class ModSmenuBanner {

	function instance_id($new = false) {
		static $num = 0;

		if ($new)
			$num++;
		else
			return $num;
	}

	function json_esc($input, $esc_lt_gt = true) {
		$result = '';
		$input = (string) $input;
		$conv = array( "'" => "'", '"' => '"', '&' => '&', '\\' => '\\', "\n" => 'n', "\r" => 'r', "\t" => 't', "\b" => 'b', "\f" => 'f' );

		if ($esc_lt_gt)
			$conv = array_merge($conv, array( '<' => 'u003C', '>' => 'u003E' ));

		for ($i = 0, $len = strlen($input); $i < $len; $i++)
			$result .= isset($conv[$input{$i}]) ? '\\' . $conv[$input{$i}] : $input{$i};

		return $result;
	}

	function norm_class($prefix, $input, &$def_classes) {
		$result = array();
		$input = trim($input);
		if ($input != '') {
			$r1 = explode(',', $input);
			foreach ($r1 as $v) {
				$v = trim($v);
				if ($v != '')
					$result[] = $v;
			}

			$def_classes .= $prefix . ': "' . array_shift($result) . '",' . "\n";
		}
		return $result;
	}

	function def_int($input, $default = 0) {
		$input = trim($input);
		return $input == '' || !ctype_digit($input) ? $default : (int) $input;
	}

	function def_float($input, $default = 0.0) {
		$input = trim($input);
		return !preg_match('/^[0-9]+(\.[0-9]*)?$/', $input) ? $default : (float) $input;
	}

	function prepare(&$params) {
		$db =& JFactory::getDBO();

		$where = array();

		$where[] = 'showBanner = 1';

		$catid = (int) $params->get('catid');
		if ($catid > 0)
			$where[] = 'catid = ' . $catid;

		$where[] = '(imptotal = 0 OR impmade < imptotal)';

		$count = (int) $params->get('count');

		$randomise = $params->get('ordering') == 'random';

		$query = "SELECT *"
			. ($randomise ? ', RAND() AS ordering' : '')
			. ' FROM #__banner'
			. ' WHERE ' . implode(' AND ', $where)
			. ' ORDER BY sticky DESC, ordering ';

		$db->setQuery($query, 0, $count);
		$result = $db->loadObjectList();

		$this->items = array();

		$this->loadit = !empty($result);

		if ($this->loadit) {
			$this->instance_id(true);

			$width = $this->def_int($params->get('width'));
			$height = $this->def_int($params->get('height'));

			if ($width == 0 && $height == 0)
				$height = 100;

			$this->div_str = '';

			if ($width > 0)
				$this->div_str .= 'width:' . $width . 'px;';

			if ($height > 0)
				$this->div_str .= 'height:' . $height . 'px;';

			if ($this->div_str != '')
				$this->div_str = ' style="' . $this->div_str . '"';

			$this->interval = $this->def_int($params->get('interval'), 20);
			$this->speed = $this->def_float($params->get('speed'), 3);
			$this->minstep = $this->def_int($params->get('minstep'));
			$this->maxstep = $this->def_int($params->get('maxstep'));
			$this->hor = $params->get('orientation', 'horizontal') == 'horizontal' ? 'true' : 'false';
			$this->align = $this->def_int($params->get('align'));
			$this->movtype = $params->get('movtype', 'plastic');
			$this->anitype = $params->get('anitype', 'static');
			$this->min_size = $this->def_int($params->get('min_size'));
			$this->large_size = $this->def_int($params->get('large_size'));
			$this->sel_permanent = $this->def_int($params->get('sel_permanent'), 1) ? 'true' : 'false';
			$this->img_start = trim($params->get('img_start'));
			$this->css_start = trim($params->get('css_start'));
			$this->img_split = trim($params->get('img_split'));
			$this->css_split = trim($params->get('css_split'));
			$this->img_end = trim($params->get('img_end'));
			$this->css_end = trim($params->get('css_end'));
			$this->def_item = $this->def_int($params->get('def_item'));
			$this->png_gif_substitution = (bool) $params->get('png_gif_substitution');

			$this->def_classes = '';
			$outer_class_norm_list = $this->norm_class('		def_outer_class_norm', $params->get('def_outer_class_norm'), $this->def_classes);
			$outer_class_sel_list = $this->norm_class('		def_outer_class_sel', $params->get('def_outer_class_sel'), $this->def_classes);
			$inner_class_norm_list = $this->norm_class('		def_inner_class_norm', $params->get('def_inner_class_norm'), $this->def_classes);
			$inner_class_sel_list = $this->norm_class('		def_inner_class_sel', $params->get('def_inner_class_sel'), $this->def_classes);
		
			$this->format = $params->get('format');
			if (trim($this->format) == '')
				$this->format = '<a href="{linkurl}">{img}</a> {title}<br/>{descr}';

			$baseurl = JURI::base();

			foreach ($result as $rec) {
				$imgurl = $baseurl . 'images/banners/' . $rec->imageurl;
				$imgpath = JPATH_SITE . '/images/banners/' . $rec->imageurl;
				$imgurl_ie6 = '';
				$imgpath_ie6 = '';

				if ($this->png_gif_substitution && preg_match('/\.png$/i', $imgurl) > 0 && file_exists(substr($imgpath, 0, -3) . 'gif')) {
					$imgurl_ie6 = substr($imgurl, 0, -3) . 'gif';
					$imgpath_ie6 = substr($imgpath, 0, -3) . 'gif';
				}

				$this->items[] = array(
					'imgurl' => $imgurl,
					'imgpath' => $imgpath,
					'imgurl_ie6' => $imgurl_ie6,
					'imgpath_ie6' => $imgpath_ie6,
					'linkurl' => $rec->clickurl,
					'format' => $rec->custombannercode,
					'descr' => $rec->description,
					'title' => $rec->name,
				);
			}
		}
	}
}

?>